summaryrefslogtreecommitdiff
path: root/svx/source/unodraw/unoshape.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'svx/source/unodraw/unoshape.cxx')
-rw-r--r--svx/source/unodraw/unoshape.cxx30
1 files changed, 15 insertions, 15 deletions
diff --git a/svx/source/unodraw/unoshape.cxx b/svx/source/unodraw/unoshape.cxx
index 839c4553a859..73872e2e4b0a 100644
--- a/svx/source/unodraw/unoshape.cxx
+++ b/svx/source/unodraw/unoshape.cxx
@@ -1538,7 +1538,7 @@ void SAL_CALL SvxShape::removeVetoableChangeListener( const OUString& , const Re
sal_Bool SAL_CALL SvxShape::SetFillAttribute( sal_Int32 nWID, const OUString& rName )
{
- SfxItemSet aSet( mpModel->GetItemPool(), (USHORT)nWID, (USHORT)nWID );
+ SfxItemSet aSet( mpModel->GetItemPool(), (sal_uInt16)nWID, (sal_uInt16)nWID );
if( SetFillAttribute( nWID, rName, aSet, mpModel ) )
{
@@ -1723,12 +1723,12 @@ sal_Bool SAL_CALL SvxShape::SetFillAttribute( sal_Int32 nWID, const OUString& rN
const SfxItemPool* pPool = rSet.GetPool();
const String aSearchName( aName );
- const sal_uInt32 nCount = pPool->GetItemCount2((USHORT)nWID);
+ const sal_uInt32 nCount = pPool->GetItemCount2((sal_uInt16)nWID);
const NameOrIndex* pItem;
for( sal_uInt32 nSurrogate = 0; nSurrogate < nCount; nSurrogate++ )
{
- pItem = (NameOrIndex*)pPool->GetItem2((USHORT)nWID, nSurrogate);
+ pItem = (NameOrIndex*)pPool->GetItem2((sal_uInt16)nWID, nSurrogate);
if( pItem && ( pItem->GetName() == aSearchName ) )
{
rSet.Put( *pItem );
@@ -1757,13 +1757,13 @@ sal_Bool SAL_CALL SvxShape::SetFillAttribute( sal_Int32 nWID, const OUString& rN
const SfxItemPool& rPool = pModel->GetItemPool();
const String aSearchName( rName );
- const sal_uInt32 nCount = rPool.GetItemCount((USHORT)nWhich);
+ const sal_uInt32 nCount = rPool.GetItemCount((sal_uInt16)nWhich);
const NameOrIndex* pItem = 0;
bool bFound = false;
for( sal_uInt32 nSurrogate = 0; ! bFound && nSurrogate < nCount; nSurrogate++ )
{
- pItem = (NameOrIndex*)rPool.GetItem((USHORT)nWhich, nSurrogate);
+ pItem = (NameOrIndex*)rPool.GetItem((sal_uInt16)nWhich, nSurrogate);
if( pItem && ( pItem->GetName() == aSearchName ) )
{
bFound = true;
@@ -2396,7 +2396,7 @@ beans::PropertyState SAL_CALL SvxShape::_getPropertyState( const OUString& Prope
case XATTR_FILLHATCH:
case XATTR_LINEDASH:
{
- NameOrIndex* pItem = (NameOrIndex*)rSet.GetItem((USHORT)pMap->nWID);
+ NameOrIndex* pItem = (NameOrIndex*)rSet.GetItem((sal_uInt16)pMap->nWID);
if( ( pItem == NULL ) || ( pItem->GetName().Len() == 0) )
eState = beans::PropertyState_DEFAULT_VALUE;
}
@@ -2411,7 +2411,7 @@ beans::PropertyState SAL_CALL SvxShape::_getPropertyState( const OUString& Prope
case XATTR_LINESTART:
case XATTR_FILLFLOATTRANSPARENCE:
{
- NameOrIndex* pItem = (NameOrIndex*)rSet.GetItem((USHORT)pMap->nWID);
+ NameOrIndex* pItem = (NameOrIndex*)rSet.GetItem((sal_uInt16)pMap->nWID);
if( ( pItem == NULL ) )
eState = beans::PropertyState_DEFAULT_VALUE;
}
@@ -2495,7 +2495,7 @@ bool SvxShape::setPropertyValueImpl( const ::rtl::OUString&, const SfxItemProper
#ifdef DBG_UTIL
SdrObject* pCheck =
#endif
- pObjList->SetObjectOrdNum( mpObj->GetOrdNum(), (ULONG)nNewOrdNum );
+ pObjList->SetObjectOrdNum( mpObj->GetOrdNum(), (sal_uIntPtr)nNewOrdNum );
DBG_ASSERT( pCheck == mpObj.get(), "GetOrdNum() failed!" );
}
return true;
@@ -2674,7 +2674,7 @@ bool SvxShape::setPropertyValueImpl( const ::rtl::OUString&, const SfxItemProper
OUString aLayerName;
if( rValue >>= aLayerName )
{
- const SdrLayer* pLayer=mpModel->GetLayerAdmin().GetLayer(aLayerName, TRUE);
+ const SdrLayer* pLayer=mpModel->GetLayerAdmin().GetLayer(aLayerName, sal_True);
if( pLayer != NULL )
{
mpObj->SetLayer( pLayer->GetID() );
@@ -2712,7 +2712,7 @@ bool SvxShape::setPropertyValueImpl( const ::rtl::OUString&, const SfxItemProper
{
Point aRef1(mpObj->GetSnapRect().Center());
double nTan=tan(nShear*nPi180);
- mpObj->Shear(aRef1,nShear,nTan,FALSE);
+ mpObj->Shear(aRef1,nShear,nTan,sal_False);
return true;
}
}
@@ -3207,13 +3207,13 @@ bool SvxShape::getPropertyValueImpl( const ::rtl::OUString&, const SfxItemProper
Graphic* pGraphic = pObj->GetGraphic();
if( pGraphic )
{
- BOOL bIsWMF = FALSE;
+ sal_Bool bIsWMF = sal_False;
if ( pGraphic->IsLink() )
{
GfxLink aLnk = pGraphic->GetLink();
if ( aLnk.GetType() == GFX_LINK_TYPE_NATIVE_WMF )
{
- bIsWMF = TRUE;
+ bIsWMF = sal_True;
uno::Sequence<sal_Int8> aSeq((sal_Int8*)aLnk.GetData(), (sal_Int32) aLnk.GetDataSize());
rValue <<= aSeq;
}
@@ -3424,7 +3424,7 @@ void SvxShape::setAllPropertiesToDefault() throw (uno::RuntimeException)
}
// #i68523# special handling for Svx3DCharacterModeItem, this is not saved
// but needs to be TRUE in svx, pool default (false) in sch. Since sch
// does not load lathe or extrude objects, it is possible to set the items
// here.
// For other solution possibilities, see task description.
@@ -3534,7 +3534,7 @@ uno::Sequence< OUString > SAL_CALL SvxShape::_getSupportedServiceNames()
if( mpObj.is() && mpObj->GetObjInventor() == SdrInventor)
{
- const UINT16 nIdent = mpObj->GetObjIdentifier();
+ const sal_uInt16 nIdent = mpObj->GetObjIdentifier();
switch(nIdent)
{
@@ -4126,7 +4126,7 @@ uno::Sequence< OUString > SAL_CALL SvxShape::_getSupportedServiceNames()
else if( mpObj.is() && mpObj->GetObjInventor() == FmFormInventor)
{
#if OSL_DEBUG_LEVEL > 0
- const UINT16 nIdent = mpObj->GetObjIdentifier();
+ const sal_uInt16 nIdent = mpObj->GetObjIdentifier();
OSL_ENSURE( nIdent == OBJ_UNO, "SvxShape::_getSupportedServiceNames: FmFormInventor, but no UNO object?" );
#endif
static uno::Sequence< OUString > *pSeq = 0;
@@ -3424,7 +3424,7 @@ void SvxShape::setAllPropertiesToDefault() throw (uno::RuntimeException)
}
// #i68523# special handling for Svx3DCharacterModeItem, this is not saved
- // but needs to be TRUE in svx, pool default (false) in sch. Since sch
+ // but needs to be sal_True in svx, pool default (false) in sch. Since sch
// does not load lathe or extrude objects, it is possible to set the items
// here.